@@ -19,7 +19,7 @@ sub login {
 sub authorized {
 	if(my $uid = $self->remote_user) {
 		my $robots = $self->cfg->allowed_robots;
-		return exists $robots->{$uid};
+		return 1 if exists $robots->{$uid};
 	}
 	my $uid = $self->SUPER::login;
 	my $users = $self->cfg->allowed_users;
