@@ -1,4 +1,4 @@
-# $Id: Alias.pm 47136 2017-11-02 13:44:40Z wsl $
+# $Id: Alias.pm 47242 2017-12-17 17:51:34Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Alias.pm $
 
 package UvT::Kiki::Database::Alias;
@@ -235,11 +235,11 @@ sub diff {
 	if(my $old = $self->original) {
 		$diff = $old->addressbook
 			? $ab
-				? "$full (in address book)\n"
-				: "$full (no longer in address book)\n"
+				? "$full (in address book):\n"
+				: "$full (no longer in address book):\n"
 			: $ab
-				? "$full (now in address book)\n"
-				: "$full (not in address book)\n";
+				? "$full (now in address book):\n"
+				: "$full (not in address book):\n";
 
 		my %destinations; @destinations{@destinations} = ();
 		my @old_destinations = map { $_->full } @{$old->destinations};
